==> haskell-x509-store-1.6.7-80-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.7
visibility:           public
id:                   x509-store-1.6.7-6K8kSM4XeME2E0e3V2GVgp
key:                  x509-store-1.6.7-6K8kSM4XeME2E0e3V2GVgp
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  cf2cee0d47b0861e51a35f7da6e05934
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-8.10.2/site-local/x509-store-1.6.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/x509-store-1.6.7
hs-libraries:         HSx509-store-1.6.7-6K8kSM4XeME2E0e3V2GVgp
depends:
    asn1-encoding-0.9.6-K1XMk5TmIZGDjbYp9ubV2M
    asn1-types-0.3.4-3gc3uGVzUrTKpuwydKTFNr base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    cryptonite-0.27-GQDFsV0e2GLJaPfeS4zGY1 directory-1.3.6.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-8TNtGXLQhpHAnyjLKb4D8e
    x509-1.7.5-DNjrBOqorKTKpkxFkmiOXb

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-x509-store-1.6.7-87-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-x509-store.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 x509-store
version:              1.6.7
visibility:           public
id:                   x509-store-1.6.7-klo4fzfa2M9BZb1a4WalP
key:                  x509-store-1.6.7-klo4fzfa2M9BZb1a4WalP
license:              BSD-3-Clause
copyright:            Vincent Hanquez <vincent@snarc.org>
maintainer:           Vincent Hanquez <vincent@snarc.org>
author:               Vincent Hanquez <vincent@snarc.org>
stability:            experimental
homepage:             http://github.com/vincenthz/hs-certificate
synopsis:             X.509 collection accessing and storing methods
description:
    X.509 collection accessing and storing methods for certificate, crl, exception list

category:             Data
abi:                  093e66adf301d8ae37b585f3c9d1b8a4
exposed:              True
exposed-modules:
    Data.X509.CertificateStore Data.X509.File Data.X509.Memory

import-dirs:          /usr/lib/ghc-8.10.2/site-local/x509-store-1.6.7
library-dirs:         /usr/lib/ghc-8.10.2/site-local/x509-store-1.6.7
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.10.2/x509-store-1.6.7
hs-libraries:         HSx509-store-1.6.7-klo4fzfa2M9BZb1a4WalP
depends:
    asn1-encoding-0.9.6-GpJnPOfFRD7EluamwB5oef
    asn1-types-0.3.4-4a0JiVqRFWwBsDXRPRDXNb base-4.14.1.0
    bytestring-0.10.10.0 containers-0.6.2.1
    cryptonite-0.27-GQDFsV0e2GLJaPfeS4zGY1 directory-1.3.6.0
    filepath-1.4.2.1 mtl-2.2.2 pem-0.2.4-1cLCN6eDsb3LR0MKXhOQMe
    x509-1.7.5-5QDWXfmTNHaJ1Yp1pjHZLG

haddock-interfaces:   /usr/share/doc/haskell-x509-store/html/x509-store.haddock
haddock-html:         /usr/share/doc/haskell-x509-store/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
